@@ -6,8 +6,7 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_CORE_SEARCHSTORE_H
-#define AKONADI_SEARCH_CORE_SEARCHSTORE_H
+#pragma once
 
 #include <QHash>
 #include <QObject>
@@ -53,7 +52,7 @@ public:
     /**
      * Executes the particular query synchronously.
      *
-     * \return Returns a integer representating the integer
+     * \return Returns a integer representing the integer
      */
     virtual int exec(const Query &query) = 0;
     virtual bool next(int queryId) = 0;
@@ -85,4 +84,3 @@ inline int deserialize(const QByteArray &namespace_, const QByteArray &str)
 
 Q_DECLARE_INTERFACE(Akonadi::Search::SearchStore, "org.kde.Akonadi.Search.SearchStore")
 
-#endif // AKONADI_SEARCH_CORE_SEARCHSTORE_H
